
#include <QApplication>
#include <QtGlobal>

#include "s60trail.h"

int main(int argc, char **argv)
{
QApplication app(argc, argv);
S60Trail *trail = new S60Trail(0);

#if !defined(Q_OS_SYMBIAN) && !defined(Q_WS_MAEMO_5) && !defined(Q_WS_MAEMO_6)
  QApplication::setStyle("meegotouch");
#endif

#if defined(Q_OS_SYMBIAN)
    app.setNavigationMode(Qt::NavigationModeKeypadTabOrder);
    trail->showMaximized();
#elif defined(Q_WS_MAEMO_5) || defined(MEEGO) || defined(Q_WS_MAEMO_6)
    trail->showFullScreen();
#else
    //This should say show(), but the MEEGO define isnt working
    trail->show();
#endif

return app.exec();

}
